import { c_unchecked } from '../helper/converter/converter';
export class ACommonList extends Array {
    constructor(items) {
        super();
        if (items) {
            this.add(items);
        }
    }
    thisAsT() {
        return c_unchecked(this);
    }
    clone() {
        return this.create(this.thisAsT());
    }
    getItems() {
        return this;
    }
    removeAll() {
        this.splice(0, this.length);
    }
    size() {
        return this.length;
    }
    isEmpty() {
        return this.size() === 0;
    }
    hasEntries() {
        return !this.isEmpty();
    }
    set(items) {
        this.removeAll();
        return this.add(items);
    }
    add(items) {
        if (Array.isArray(items)) {
            for (const item of items) {
                this.push(item);
            }
        }
        else if (items) {
            this.push(items);
        }
        return this.thisAsT();
    }
    addIf(items, filterFn) {
        if (Array.isArray(items)) {
            for (const item of items) {
                if (item && filterFn(item)) {
                    this.add(item);
                }
            }
        }
        else {
            if (items && filterFn(items)) {
                this.add(items);
            }
        }
        return this.thisAsT();
    }
    addIfAbsent(items) {
        return this.addIf(items, (item) => this.containsNone(item));
    }
    remove(items) {
        if (Array.isArray(items)) {
            for (const item of items) {
                if (item) {
                    const itemIndex = this.indexOf(item);
                    if (itemIndex !== -1) {
                        this.splice(itemIndex, 1);
                    }
                }
            }
        }
        else if (items) {
            const itemIndex = this.indexOf(items);
            if (itemIndex !== -1) {
                this.splice(itemIndex, 1);
            }
        }
        return this.thisAsT();
    }
    removeIf(items, filterFn) {
        if (Array.isArray(items)) {
            for (const item of items) {
                if (item && filterFn(item)) {
                    const itemIndex = this.indexOf(item);
                    if (itemIndex !== -1) {
                        this.splice(itemIndex, 1);
                    }
                }
            }
        }
        else if (items && filterFn(items)) {
            const itemIndex = this.indexOf(items);
            if (itemIndex !== -1) {
                this.splice(itemIndex, 1);
            }
        }
        return this.thisAsT();
    }
    removeIfPresent(items) {
        return this.removeIf(items, (item) => {
            return this.containsAny(item);
        });
    }
    containsDuplicates() {
        return this.length !== new Set(this).size;
    }
    containsAny(item) {
        if (!item) {
            return false;
        }
        return this.includes(item);
    }
    containsNone(item) {
        if (!item) {
            return false;
        }
        return !this.includes(item);
    }
    map(callbackFn) {
        const result = this.createSimpleList();
        for (let index = 0; index < this.length; index++) {
            result.add(callbackFn(this[index], index, this.thisAsT()));
        }
        return result;
    }
    pluck(key) {
        return this.map((item) => item[key]);
    }
    forEachIf(callbackFn, filterFn) {
        for (const item of this) {
            if (item && filterFn(item)) {
                callbackFn(item);
            }
        }
        return this.thisAsT();
    }
    computeIfPresent(items, callbackFn) {
        return this.computeIf(items, callbackFn, (item) => this.containsAny(item));
    }
    computeIfAbsent(items, callbackFn) {
        return this.computeIf(items, callbackFn, (item) => this.containsNone(item));
    }
    computeIf(items, callbackFn, filterFn) {
        if (Array.isArray(items)) {
            for (const item of items) {
                if (item && filterFn(item)) {
                    callbackFn(item);
                }
            }
        }
        else if (items && filterFn(items)) {
            callbackFn(items);
        }
        return this.thisAsT();
    }
    shuffle() {
        for (let i = this.length - 1; i > 0; i--) {
            const j = Math.floor(Math.random() * (i + 1));
            [this[i], this[j]] = [this[j], this[i]];
        }
        return this.thisAsT();
    }
}
//# sourceMappingURL=list.abstract.js.map